# About pid4cat-model

## Authors & contributors

see [README](https://github.com/nfdi4cat/pid4cat-model?tab=readme-ov-file#contributors)

## License

- Source code, data model: MIT
- Documentation, images:  CC-BY 4.0

## Acknowledgement

[linkml-project-copier](https://github.com/linkml/linkml-project-cookiecutter) provides the underlying template of the current repository.
Earlier we used [linkml-project-cookiecutter](https://github.com/linkml/linkml-project-cookiecutter) as template.

This project started as an in-kind contribution of [Leibniz-Institut für Katalyse e.V.](https://www.catalysis.de) (Rostock, Germany) to the NFDI4Cat project.

After 2024-03-27 this work has been funded by the German Research Foundation (DFG) through the project "[NFDI4Cat](https://www.nfdi4cat.org) - NFDI for Catalysis-Related Sciences" (DFG project no. [441926934](https://gepris.dfg.de/gepris/projekt/441926934)),
within the National Research Data Infrastructure ([NFDI](https://www.nfdi.de)) programme of the Joint Science Conference (GWK).
